@@ -71,13 +71,14 @@ pbat.clean <- function( pbatObj, plots=TRUE, all.output=FALSE ){
 
   ## What about the pbatlog files and pbatstatus files generated by pbat?
   if( all.output==TRUE ){
-    safedel("pbatstatus.txt");
-    safedel("spluscode.txt");
-    ## delete all output from pbat - WARNING - not just from this run!
-    pbatlogs <- dir( pattern="pbatlog.*" ); # regular expressions
-    if( length(pbatlogs)>0 ) {
-      for( i in 1:length(pbatlogs) )
-        safedel( pbatlogs );
-    }
+#     safedel("pbatstatus.txt");
+#     safedel("spluscode.txt");
+#     ## delete all output from pbat - WARNING - not just from this run!
+# 
+#     pbatlogs <- dir( pattern="pbatlog.*" ); # regular expressions
+#     if( length(pbatlogs)>0 ) {
+#       for( i in 1:length(pbatlogs) )
+#         safedel( pbatlogs );
+#     }
   }
 }
